Crate tokio_utils
source ·Expand description
Tools for asynchronous programming in Tokio applications
Resource Pooling
Pool, a shared resource pool
Rate Limiting
RateLimiter, a rate limiterMultiRateLimiter, a key-based rate limiter
Graceful Shutdown
ShutdownController, a controller for graceful shutdownShutdownMonitor, a monitor for graceful shutdown
Stdin
recv_from_stdin, a channel that receives data from stdin
Structs
MultiRateLimiterenables key-based rate limiting, where each key has its ownRateLimiter.- A shared resource pool
RateLimiteris a tool which can control the rate at which processing happens.- A
ShutdownControlleris used to control the shutdown of an application. - A
ShutdownMonitorlistens for the shutdown signal from aShutdownControllerand tracks that the signal has been received.
Functions
- Returns a [
mpsc::Receiver] that contains the input fromstdin